@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from . import views
 
 PACKAGE = r'(?P<package_name>[\w\d_\.\-]+)'
@@ -7,8 +7,8 @@ VERSION = r'(?P<version>[\w\d_\.\-]+)'
 urlpatterns = patterns('',
     url('^$', views.index, name="djangopypi2-root"),
 
-    url('^simple/$'                , views.simple_index   , name='djangopypi2-simple-index'),
-    url('^simple/' + PACKAGE + '/$', views.simple_details , name='djangopypi2-simple-package-info'),
+    url('^simple/$'                , views.SimpleIndex.as_view(), name='djangopypi2-simple-index'),
+    url('^simple/' + PACKAGE + '/$', views.simple_details       , name='djangopypi2-simple-package-info'),
 
     url('^pypi/$'                                          , views.index          , name='djangopypi2-pypi-index'),
     url('^pypi/' + PACKAGE + '/$'                          , views.package_details, name='djangopypi2-pypi-package'),
